@@ -123,6 +123,8 @@ class MediaWikiCluster(object):
                     mwApp.installExtensions()
                     # then create and fill database and update it
                     mwApp.initDB()
+                    # then run startUp scripts
+                    mwApp.startUp()
                     
         return 0
             
@@ -152,7 +154,7 @@ class MediaWikiCluster(object):
         mwApp=DockerApplication(user=self.user,password=self.password,version=version,extensionMap=self.extensionMap,wikiId=wikiId,mariaDBVersion=self.mariaDBVersion,smwVersion=self.smwVersion,port=port,sqlPort=sqlPort,mySQLRootPassword=self.mySQLRootPassword,logo=self.logo,debug=True)
         return mwApp
 
-__version__ = "0.1.6"
+__version__ = "0.1.9"
 __date__ = '2021-06-21'
 __updated__ = '2021-07-05'
 DEBUG=False
