@@ -1,4 +1,4 @@
-#!/ bin/bash
+#!/bin/bash
 # WF 2021-07-05
 jobs=$(pgrep -fla runjobs | wc -l)
 if [ $jobs -gt 3 ]
@@ -6,5 +6,6 @@ then
   echo "$jobs runjobs already running ..."
   exit 1
 fi
+cd /var/www/html
 
-php maintainance/runjobs.php
\ No newline at end of file
+php maintenance/runJobs.php >> /var/log/mediawiki/runJobs.log 2>&1
\ No newline at end of file
